import 'package:flutter/material.dart';
import 'package:practica1_flutter/src/controllers/category_controller.dart';
import 'package:practica1_flutter/src/models/category_model.dart';
import 'package:practica1_flutter/src/pages/articles_page.dart';

class CategoryWidget extends StatefulWidget {
  @override
  _CategoryWidgetState createState() => _CategoryWidgetState();
}

class _CategoryWidgetState extends State<CategoryWidget> {
  final CategoryController _categoryCtrl = CategoryController();

  @override
  Widget build(BuildContext context) {
    return SafeArea(
      child: Padding(
        padding: const EdgeInsets.all(16.0),
        child: FutureBuilder<Map<String, dynamic>>(
          future: _categoryCtrl.getCategories(),
          builder: (context, snapshot) {
            if (snapshot.hasData) {
              if (snapshot.data!['ok']) {
                if (snapshot.data!['data'] != null && (snapshot.data!['data'] as List).isNotEmpty) {
                  List<CategoryModel> categories = snapshot.data!['data'];
                  return ListView.builder(
                    itemBuilder: (BuildContext context, int index) {
                      final category = categories[index];
                      return Card(
                        child: ListTile(
                          title: Text(category.name ?? 'No Name'),
                          leading: const Icon(Icons.touch_app),
                          onTap: () {
                            // Navegar al listado de artículos y pasa el ID de la categoría
                            Navigator.push(
                              //El push lo que hace es empujar la ruta dada por medio de la clase
                              // MaterialPageRoute, en esta clase se envía el contexto y el widget
                              // de la nueva pantalla que va a mostrar.
                              context,
                              MaterialPageRoute(
                                builder: (context) => ArticlePage(
                                  categoryId: category.id,
                                ),
                              ),
                            );
                          },
                        ),
                      );
                    },
                    itemCount: categories.length,
                  );
                } else {
                  return Center(child: Text("No se encontraron categorías"));
                }
              } else {
                return Center(child: Text("Error: ${snapshot.data!['message']}"));
              }
            } else if (snapshot.hasError) {
              return Center(child: Text("Error: ${snapshot.error.toString()}"));
            } else {
              return const Center(
                child: CircularProgressIndicator(),
              );
            }
          },
        ),
      ),
    );
  }
}
